@@ -36,6 +36,7 @@ static char sccsid[] = "@(#)ftpd.c	5.27.1.1	(Berkeley) 3/2/89";
 #include <sys/file.h>
 #include <sys/wait.h>
 #include <dirent.h>
+#include <time.h>
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -88,8 +89,8 @@ static char sccsid[] = "@(#)ftpd.c	5.27.1.1	(Berkeley) 3/2/89";
 extern	int errno;
 #ifndef STDIO_DECLARES_SYS_ERRLIST
 extern	char *sys_errlist[];
-#endif
 extern	int sys_nerr;
+#endif
 extern	char *crypt();
 extern	char *ctime();
 extern	char version[];
@@ -591,7 +592,7 @@ pass(passwd)
 		reply(230, "Guest login ok, access restrictions apply.");
 	    } else {
 		FILE *motd;
-		long t;
+		time_t t;
 
 		lreply(230, "Guest login ok, access restrictions apply.");
 
@@ -647,7 +648,7 @@ retrieve(cmd, name)
 	struct stat st;
 	int (*closefunc)();
 #ifdef STATS
-	long start;
+	time_t start;
 #endif
 
 	if (cmd == 0) {
@@ -790,7 +791,7 @@ dataconn(name, size, mode)
 		timeout.tv_usec = 0;
 		timeout.tv_sec = 120;
 
-		if (select(pdata+1, &set, (fd_set *) 0, (fd_set *) 0, &timeout) == 0 ||
+		if (select(pdata+1, &set, (fd_set *) 0, (fd_set *) 0, &timeout) <= 0 ||
 		    (s = accept(pdata, (struct sockaddr *) &from, &fromlen)) < 0) {
 			reply(425, "Can't open data connection.");
 			(void) close(pdata);
