@@ -94,7 +94,6 @@ you lose
 
 /* Ultrix. */
 #ifndef LOG_AUTH
-#define LOG_AUTH	0
 #define LOG_CONS	0
 #endif
 
@@ -164,7 +163,11 @@ main(argc, argv)
 		prio = 0;
 	(void)setpriority(PRIO_PROCESS, 0, -2);
 #endif
-	openlog("su", LOG_CONS, 0);
+#ifdef LOG_AUTH
+	openlog("su", LOG_CONS, FACILITY);
+#else
+	openlog("su", LOG_CONS);
+#endif
 
 	/* get current login name and shell */
 	ruid = getuid();
@@ -241,7 +244,7 @@ main(argc, argv)
 			if (strcmp(pwd->pw_passwd, crypt(p, pwd->pw_passwd))) {
 #endif /* SKEY */
 				fprintf(stderr, "Sorry\n");
-				syslog(FACILITY|LOG_WARNING,
+				syslog(LOG_WARNING,
 #ifdef sun /* generate SunOS-like syslog messages */
 					"'su %s' failed for %s%s", user,
 					username, ontty());
@@ -329,11 +332,11 @@ main(argc, argv)
 	*np = asthem ? "-su" : iscsh == YES ? "_su" : "su";
 
 #ifdef sun /* generate SunOS-like syslog messages */
-	syslog(LOG_NOTICE|LOG_AUTH, "'su %s' succeeded for %s%s",
+	syslog(LOG_NOTICE, "'su %s' succeeded for %s%s",
 	    user, username, ontty());
 #else
 	if (ruid != 0)
-		syslog(LOG_NOTICE|LOG_AUTH, "%s to %s%s",
+		syslog(LOG_NOTICE, "%s to %s%s",
 		    username, user, ontty());
 #endif
 
@@ -369,7 +372,7 @@ ontty()
 		sprintf(buf, " on %s", p);
 	if (p = utmp_host()) {
 		strcat(buf, " from ");
-		strcat(buf, p);
+		strncat(buf, p, 100);
 	}
 	return (buf);
 }
@@ -432,7 +435,7 @@ kerberos(username, user, uid)
 		}
 		(void)fprintf(stderr, "su: unable to su: %s\n",
 		    krb_err_txt[kerno]);
-		syslog(LOG_NOTICE|LOG_AUTH,
+		syslog(LOG_NOTICE,
 		    "BAD Kerberos SU: %s to %s%s: %s",
 		    username, user, ontty(), krb_err_txt[kerno]);
 		return (1);
@@ -459,14 +462,14 @@ kerberos(username, user, uid)
 
 	if (kerno == KDC_PR_UNKNOWN) {
 		(void)fprintf(stderr, "Warning: TGT not verified.\n");
-		syslog(LOG_NOTICE|LOG_AUTH,
+		syslog(LOG_NOTICE,
 		    "%s to %s%s, TGT not verified (%s); %s.%s not registered?",
 		    username, user, ontty(), krb_err_txt[kerno],
 		    "rcmd", savehost);
 	} else if (kerno != KSUCCESS) {
 		(void)fprintf(stderr, "Unable to use TGT: %s\n",
 		    krb_err_txt[kerno]);
-		syslog(LOG_NOTICE|LOG_AUTH, "failed su: %s to %s%s: %s",
+		syslog(LOG_NOTICE, "failed su: %s to %s%s: %s",
 		    username, user, ontty(), krb_err_txt[kerno]);
 		dest_tkt();
 		return (1);
@@ -484,7 +487,7 @@ kerberos(username, user, uid)
 			(void)fprintf(stderr,
 			    "su: unable to verify rcmd ticket: %s\n",
 			    krb_err_txt[kerno]);
-			syslog(LOG_NOTICE|LOG_AUTH,
+			syslog(LOG_NOTICE,
 			    "failed su: %s to %s%s: %s", username,
 			     user, ontty(), krb_err_txt[kerno]);
 			dest_tkt();
