@@ -2,7 +2,7 @@
 #include <sys/file.h>
 #include <string.h>
 #include <utmp.h>
-#include <linux/fcntl.h>
+#include <fcntl.h>
 
 #ifndef _PATH_UTMP
 #define	_PATH_UTMP	"/etc/utmp"
